@@ -12,7 +12,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-medialive", "1.99.0", __name__[0:-6], "aws-medialive@1.99.0.jsii.tgz"
+    "@aws-cdk/aws-medialive",
+    "1.102.0",
+    __name__[0:-6],
+    "aws-medialive@1.102.0.jsii.tgz",
 )
 
 __all__ = [
